@@ -27,7 +27,11 @@
  * Version 2.0.5
  * Compatibility with OpenSSL 0.9.4
  *
- * Copyright 1997-9 Rick R. Kaseguma
+ * Version 2.0.6
+ * Changed Malloc to malloc and Free to free
+ * Changed #include "err.h" to #include OPENSSL"err.h"
+ *
+ * Copyright 1997-9, 2000 Rick R. Kaseguma
  * All rights reserved
  *
  * Feel free to use this as you want for commercial or non-commercial use,
@@ -121,7 +125,7 @@
 #include OPENSSL"bn.h"
 #define USE_SOCKETS
 #include "apps.h"
-#include "err.h"
+#include OPENSSL"err.h"
 #include OPENSSL"pem.h"
 #include OPENSSL"x509.h"
 #include OPENSSL"ssl.h"
@@ -618,7 +622,7 @@ int s_stdout;
 #endif /*NO_EXEC*/
 	}
 
-	if ((buf=Malloc(BUFSIZZ)) == NULL)
+	if ((buf=malloc(BUFSIZZ)) == NULL)
 		{
 		BIO_printf(bio_err,"out of memory\n");
 		goto err;
@@ -725,7 +729,7 @@ err:
 	if (buf != NULL)
 		{
 		memset(buf,0,BUFSIZZ);
-		Free(buf);
+		free(buf);
 		}
 
 	return(ret);
